# Changelog

## 0.1.0 (2025-10-24)

Full Changelog: [v0.0.2...v0.1.0](https://github.com/DeepSourceCorp/autofixbot-python/compare/v0.0.2...v0.1.0)

### Features

* **api:** update pypi name to autofixbot ([993016e](https://github.com/DeepSourceCorp/autofixbot-python/commit/993016e8634e2592e48d5e7c349fe38048443cad))

## 0.0.2 (2025-10-24)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/DeepSourceCorp/autofixbot-python/compare/v0.0.1...v0.0.2)

### Chores

* update SDK settings ([4d07ffb](https://github.com/DeepSourceCorp/autofixbot-python/commit/4d07ffb1d2875c50356f3f62af6a54a02283d09f))
* update SDK settings ([3200c88](https://github.com/DeepSourceCorp/autofixbot-python/commit/3200c8819d2ebcf26ce0779a5e12c20edb8cfa68))
